@@ -21,6 +21,7 @@
  */
 
 #include "gnome-icon-lookup.h"
+#include "gnome-icon-theme.h"
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs.h>
 
@@ -210,7 +211,7 @@ mimetype_supported_by_gdk_pixbuf (const char *mime_type)
 
 /**
  * gnome_icon_lookup:
- * @icon_theme: a #GnomeIconTheme
+ * @icon_theme: a #GtkIconTheme, or (deprecated) a #GnomeIconTheme
  * @thumbnail_factory: an optional #GnomeThumbnailFactory used to look up thumbnails
  * @file_uri: the uri of the file
  * @custom_icon: optionally the name of a custom icon to try
@@ -226,6 +227,9 @@ mimetype_supported_by_gdk_pixbuf (const char *mime_type)
  * If you don't know any information about the file already you can use
  * gnome_icon_lookup_sync() which gets this information using gnome-vfs.
  *
+ * For backwards compatibility, this function also accepts a GnomeIconTheme
+ * instead of a GtkIconTheme.
+ *
  * The following @flags are valid:
  * 
  * GNOME_ICON_LOOKUP_FLAGS_EMBEDDING_TEXT - Return the text icon for scripts.
@@ -243,7 +247,7 @@ mimetype_supported_by_gdk_pixbuf (const char *mime_type)
  *          use for the file.
  **/
 char *
-gnome_icon_lookup (GnomeIconTheme             *icon_theme,
+gnome_icon_lookup (GtkIconTheme               *icon_theme,
 		   GnomeThumbnailFactory      *thumbnail_factory,
 		   const char                 *file_uri,
 		   const char                 *custom_icon,
@@ -257,6 +261,16 @@ gnome_icon_lookup (GnomeIconTheme             *icon_theme,
   char *thumbnail;
   time_t mtime;
 
+  /* For backwards compat we support GnomeIconTheme too */
+  if (GNOME_IS_ICON_THEME (icon_theme))
+    {
+      if (gnome_icon_theme_get_allow_svg (GNOME_ICON_THEME (icon_theme)))
+	flags |= GNOME_ICON_LOOKUP_FLAGS_ALLOW_SVG_AS_THEMSELVES;
+      icon_theme = _gnome_icon_theme_get_gtk_icon_theme (GNOME_ICON_THEME (icon_theme));
+    }
+
+  g_return_val_if_fail (GTK_IS_ICON_THEME (icon_theme), NULL);
+  
   if (result)
     *result = GNOME_ICON_LOOKUP_RESULT_FLAGS_NONE;
 
@@ -265,7 +279,7 @@ gnome_icon_lookup (GnomeIconTheme             *icon_theme,
     {
       /* WARNING: Does I/O for abs custom icons! */
       if ((custom_icon[0] == '/' && g_file_test (custom_icon, G_FILE_TEST_IS_REGULAR)) ||
-	  gnome_icon_theme_has_icon (icon_theme, custom_icon))
+	  gtk_icon_theme_has_icon (icon_theme, custom_icon))
 	return g_strdup (custom_icon);
     }
 
@@ -273,8 +287,9 @@ gnome_icon_lookup (GnomeIconTheme             *icon_theme,
     {
       if (flags & GNOME_ICON_LOOKUP_FLAGS_SHOW_SMALL_IMAGES_AS_THEMSELVES &&
 	  (mimetype_supported_by_gdk_pixbuf (mime_type) ||
-	   (strcmp (mime_type, "image/svg") == 0 &&
-	    gnome_icon_theme_get_allow_svg (icon_theme)))  &&
+	   ((strcmp (mime_type, "image/svg") == 0 ||
+	     strcmp (mime_type, "image/svg+xml") == 0) &&
+	    flags & GNOME_ICON_LOOKUP_FLAGS_ALLOW_SVG_AS_THEMSELVES))  &&
 	  strncmp (file_uri, "file:/", 6) == 0 &&
 	  file_info && file_info->size < SELF_THUMBNAIL_SIZE_THRESHOLD)
 	return gnome_vfs_get_local_path_from_uri (file_uri);
@@ -298,24 +313,24 @@ gnome_icon_lookup (GnomeIconTheme             *icon_theme,
     {
       mime_name = get_vfs_mime_name (mime_type);
       if (mime_name &&
-	  ((mime_name[0] == '/' &&  g_file_test (mime_name, G_FILE_TEST_IS_REGULAR) ||
-	    gnome_icon_theme_has_icon (icon_theme, mime_name))))
+	  ((mime_name[0] == '/' &&  g_file_test (mime_name, G_FILE_TEST_IS_REGULAR)) ||
+	   gtk_icon_theme_has_icon (icon_theme, mime_name)))
 	return mime_name;
       g_free (mime_name);
       
       mime_name = make_mime_name (mime_type);
-      if (mime_name && gnome_icon_theme_has_icon (icon_theme, mime_name))
+      if (mime_name && gtk_icon_theme_has_icon (icon_theme, mime_name))
 	return mime_name;
       g_free (mime_name);
       
       mime_name = make_generic_mime_name (mime_type, flags & GNOME_ICON_LOOKUP_FLAGS_EMBEDDING_TEXT);
-      if (mime_name && gnome_icon_theme_has_icon (icon_theme, mime_name))
+      if (mime_name && gtk_icon_theme_has_icon (icon_theme, mime_name))
 	return mime_name;
       g_free (mime_name);
     }
       
   icon_name = get_icon_name (file_uri, file_info, mime_type, flags);
-  if (icon_name && gnome_icon_theme_has_icon (icon_theme, icon_name))
+  if (icon_name && gtk_icon_theme_has_icon (icon_theme, icon_name))
     return icon_name;
   g_free (icon_name);
 
@@ -324,7 +339,7 @@ gnome_icon_lookup (GnomeIconTheme             *icon_theme,
 
 /**
  * gnome_icon_lookup_sync:
- * @icon_theme: a #GnomeIconTheme
+ * @icon_theme: a #GtkIconTheme, or (deprecated) a #GnomeIconTheme
  * @thumbnail_factory: an optional #GnomeThumbnailFactory used to look up thumbnails
  * @file_uri: the uri of the file
  * @custom_icon: optionally the name of a custom icon to try
@@ -338,7 +353,7 @@ gnome_icon_lookup (GnomeIconTheme             *icon_theme,
  *          use for the file.
  */
 char *
-gnome_icon_lookup_sync (GnomeIconTheme          *icon_theme,
+gnome_icon_lookup_sync (GtkIconTheme            *icon_theme,
 			GnomeThumbnailFactory   *thumbnail_factory,
 			const char              *file_uri,
 			const char              *custom_icon,
